@@ -58,6 +58,7 @@ from univention.management.console.resource import Resource
 from univention.management.console.shared_memory import shared_memory
 
 
+PORT = None
 try:
     from time import monotonic
 except ImportError:
@@ -173,7 +174,7 @@ class SAMLResource(Resource):
     requires_authentication = False
 
     SP = None
-    identity_cache = '/var/cache/univention-management-console/saml.bdb' if ucr.is_false('umc/saml/in-memory-identity-cache') else None
+    identity_cache = '/var/cache/univention-management-console/saml-%d.bdb' if ucr.is_false('umc/saml/in-memory-identity-cache') else None
     configfile = '/usr/share/univention-management-console/saml/sp.py'
     idp_query_param = "IdpQuery"
     bindings = [BINDING_HTTP_REDIRECT, BINDING_HTTP_POST, BINDING_HTTP_ARTIFACT]
@@ -210,8 +211,9 @@ class SamlACS(SAMLResource):
     def reload(cls):
         CORE.info('Reloading SAML service provider configuration')
         sys.modules.pop(os.path.splitext(os.path.basename(cls.configfile))[0], None)
+        identity_cache = cls.identity_cache % (PORT,) if cls.identity_cache else None
         try:
-            cls.SP = Saml2Client(config_file=cls.configfile, identity_cache=cls.identity_cache, state_cache=shared_memory.saml_state_cache)
+            cls.SP = Saml2Client(config_file=cls.configfile, identity_cache=identity_cache, state_cache=shared_memory.saml_state_cache)
             return True
         except Exception:
             CORE.warn('Startup of SAML2.0 service provider failed:\n%s' % (traceback.format_exc(),))
